pub struct HTTPServer {
pub addr: Vec<SocketAddr>,
pub paths: Vec<Path>,
pub listeners: Vec<Listener>,
pub on_ready: Option<SoftListener>,
pub on_shutdown: Option<SoftListener>,
pub on_error: Option<ErrorListener>,
pub thread_pool: ThreadPool,
pub should_shutdown: ShutdownWrapper,
}Expand description
This struct provide a simple http server that handle many of the use cases
Example
use mini_server::*;
let mut app = HTTPServer::default();
app.get("/", |_, _| {
"Hello World!".into()
});
Path
The path is an expression that can contains dynamic variables.
- Basic paths:
/,/this/is/a/path, … - Dynamic path:
/this/is/a/@varibale,/this/is/another/#variable
# and @ are prefixes for dynamic values. # for denoting numbers
and @ for strings. float can start with a dot (.)
Fields
addr: Vec<SocketAddr>paths: Vec<Path>listeners: Vec<Listener>on_ready: Option<SoftListener>on_shutdown: Option<SoftListener>on_error: Option<ErrorListener>thread_pool: ThreadPoolshould_shutdown: ShutdownWrapperImplementations
Sourceimpl HTTPServer
impl HTTPServer
pub fn get<T>(&mut self, path: &'static str, handler: T)
pub fn post<T>(&mut self, path: &'static str, handler: T)
pub fn put<T>(&mut self, path: &'static str, handler: T)
pub fn delete<T>(&mut self, path: &'static str, handler: T)
pub fn patch<T>(&mut self, path: &'static str, handler: T)
pub fn options<T>(&mut self, path: &'static str, handler: T)
pub fn head<T>(&mut self, path: &'static str, handler: T)
pub fn trace<T>(&mut self, path: &'static str, handler: T)
pub fn connect<T>(&mut self, path: &'static str, handler: T)